@@ -1,7 +1,6 @@
 package CPANPLUS::YACSmoke;
-$CPANPLUS::YACSmoke::VERSION = '1.03_04'; # TRIAL
-
-$CPANPLUS::YACSmoke::VERSION = '1.0304';# Dist::Zilla: +PodWeaver
+$CPANPLUS::YACSmoke::VERSION = '1.02';
+# Dist::Zilla: +PodWeaver
 #ABSTRACT: Yet Another CPANPLUS Smoke Tester
 
 use strict;
@@ -97,7 +96,6 @@ sub new {
 
   my $exclude_dists;
   my $exclude_auths;
-  my $local_lib;
   my $config_file = catfile( $conf->get_conf('base'), CONFIG_FILE );
   if ( -r $config_file ) {
      my $cfg = CPANPLUS::YACSmoke::IniFiles->new(-file => $config_file);
@@ -115,7 +113,6 @@ sub new {
           $exclude_auths->add( @list );
        }
      }
-     $local_lib = $cfg->val( 'CONFIG', 'local::lib' );
   }
 
   my $self = bless { @_ }, $package;
@@ -124,7 +121,6 @@ sub new {
   $self->{exclude_dists} = $exclude_dists;
   $self->{exclude_auths} = $exclude_auths;
   $self->{allow_retries} = 'aborted|ungraded';
-  $self->{local_lib}     = $local_lib;
   return $self;
 }
 
@@ -159,36 +155,19 @@ sub test {
 
   $self->_disconnect_db();
 
-  my $target = 'create';
-
-  if ( $self->{local_lib} ) {
-     $self->_setup_local_lib();
-     $self->{conf}->_perl5lib( $ENV{PERL5LIB} );
-     $target = 'install';
-     msg("Setup local::lib environment in '$ENV{PERL_LOCAL_LIB_ROOT}'");
-  }
-
   foreach my $mod ( @mods ) {
      eval {
 		CPANPLUS::Error->flush();
 		my $stat = $self->{cpanplus}->install(
 				modules  => [ $mod ],
-				target   => $target,
+				target   => 'create',
 				allow_build_interactively => 0,
 				# other settings now set via set_config() method
 		);
      };
   }
 
-  if ( $self->{local_lib} ) {
-    my $build_dir = $self->_get_build_dir();
-    msg("Flushing '$build_dir'");
-    rmtree($build_dir) if -e $build_dir;
-    msg("Flushed '$build_dir'");
-  }
-
-  $self->{cpanplus}->save_state() if !$self->{local_lib};
-
+  $self->{cpanplus}->save_state();
   return 1;
 }
 
@@ -455,18 +434,6 @@ sub _get_build_dir {
   );
 }
 
-sub _setup_local_lib {
-  my $self = shift;
-  return if !$self->{local_lib};
-  require Cwd;
-  require File::Temp;
-  require CPANPLUS::YACSmoke::locallib;
-  my $tmpdir = File::Temp::tempdir( DIR => '.', CLEANUP => 1 );
-  my $abs = Cwd::abs_path($tmpdir);
-  CPANPLUS::YACSmoke::locallib->ensure_dir_structure_for( $abs, { quiet => 1 } );
-  CPANPLUS::YACSmoke::locallib->setup_env_hash_for( $abs );
-}
-
 }
 
 'Yakkity Yac';
@@ -483,7 +450,7 @@ CPANPLUS::YACSmoke - Yet Another CPANPLUS Smoke Tester
 
 =head1 VERSION
 
-version 1.03_04
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -534,17 +501,6 @@ a particular CPAN author ID.
 The above would ignore all distributions of any CPAN author ID that
 begins with C<ASS>, such as C<ASSAM> and C<ASSONIA>.
 
-Experimental support for L<local::lib> type environment has been added.
-In the C<ini> file specify the C<local::lib> setting to enable this feature.
-
-  [CONFIG]
-  local::lib = 1
-
-Setting this will make CPANPLUS::YACSmoke setup a L<local::lib> under the
-current working directory before testing starts. All modules tested (and prereqs
-resolved during testing) will be installed into the L<local::lib>. When testing
-finishes, the L<local::lib> will be removed.
-
 See L<Config::IniFiles> for more information on the INI file format.
 
 =head1 PROCEDURAL INTERFACE
@@ -716,7 +672,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
+This software is copyright (c) 2017 by Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
