@@ -1,7 +1,6 @@
 package CPANPLUS::YACSmoke::IniFiles;
-$CPANPLUS::YACSmoke::IniFiles::VERSION = '1.03_04'; # TRIAL
-
-$CPANPLUS::YACSmoke::IniFiles::VERSION = '1.0304';require 5.004;
+$CPANPLUS::YACSmoke::IniFiles::VERSION = '1.02';
+require 5.004;
 use strict;
 use Carp;
 use Symbol 'gensym','qualify_to_ref';   # For the 'any data type' hack
@@ -2183,9 +2182,8 @@ sub _make_filehandle {
 # 2000.May.09 Created to excapsulate TIEHASH interface    JW
 ############################################################
 package Config::IniFiles::_section;
-$Config::IniFiles::_section::VERSION = '1.03_04'; # TRIAL
-
-$Config::IniFiles::_section::VERSION = '1.0304';use strict;
+$Config::IniFiles::_section::VERSION = '1.02';
+use strict;
 use Carp;
 
 # ----------------------------------------------------------
