@@ -7,9 +7,8 @@
 # the same terms as Perl itself.
 
 package CPANPLUS::YACSmoke::SortVers;
-$CPANPLUS::YACSmoke::SortVers::VERSION = '1.03_04'; # TRIAL
-
-$CPANPLUS::YACSmoke::SortVers::VERSION = '1.0304';require Exporter;
+$CPANPLUS::YACSmoke::SortVers::VERSION = '1.02';
+require Exporter;
 @ISA=qw(Exporter);
 
 @EXPORT=qw(&versions &versioncmp);
